@@ -1,4 +1,4 @@
-# $Id: CreateCDImage.pm,v 1.4 2003/01/28 20:19:57 joern Exp $
+# $Id: CreateCDImage.pm,v 1.5 2004/04/11 23:36:20 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
@@ -9,6 +9,7 @@
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::CreateCDImage;
+use Locale::TextDomain qw (video.dvdrip);
 
 use base Video::DVDRip::Job;
 
@@ -28,7 +29,7 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info = "Create CD image";
+	my $info = __"Create CD image";
 
 	return $info;
 }
